==> zio-aws-globalaccelerator_2.13-5.17.163.1-sources.jar: zio/aws/globalaccelerator/model/Accelerator.scala <==
package zio.aws.globalaccelerator.model
import zio.aws.globalaccelerator.model.primitives.{
  Timestamp,
  GenericBoolean,
  GenericString
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class Accelerator(
    acceleratorArn: Optional[GenericString] = Optional.Absent,
    name: Optional[GenericString] = Optional.Absent,
    ipAddressType: Optional[zio.aws.globalaccelerator.model.IpAddressType] =
      Optional.Absent,
    enabled: Optional[GenericBoolean] = Optional.Absent,
    ipSets: Optional[Iterable[zio.aws.globalaccelerator.model.IpSet]] =
      Optional.Absent,
    dnsName: Optional[GenericString] = Optional.Absent,
    status: Optional[zio.aws.globalaccelerator.model.AcceleratorStatus] =
      Optional.Absent,
    createdTime: Optional[Timestamp] = Optional.Absent,
    lastModifiedTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.Accelerator = {
    import Accelerator.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.Accelerator
      .builder()
      .optionallyWith(acceleratorArn.map(value => value: java.lang.String))(
        _.acceleratorArn
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(
        ipSets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipSets)
      .optionallyWith(dnsName.map(value => value: java.lang.String))(_.dnsName)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        createdTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdTime)
      .optionallyWith(
        lastModifiedTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .build()
  }
  def asReadOnly: zio.aws.globalaccelerator.model.Accelerator.ReadOnly =
    zio.aws.globalaccelerator.model.Accelerator.wrap(buildAwsValue())
}
object Accelerator {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.Accelerator
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.globalaccelerator.model.Accelerator =
      zio.aws.globalaccelerator.model.Accelerator(
        acceleratorArn.map(value => value),
        name.map(value => value),
        ipAddressType.map(value => value),
        enabled.map(value => value),
        ipSets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dnsName.map(value => value),
        status.map(value => value),
        createdTime.map(value => value),
        lastModifiedTime.map(value => value)
      )
    def acceleratorArn: Optional[GenericString]
    def name: Optional[GenericString]
    def ipAddressType: Optional[zio.aws.globalaccelerator.model.IpAddressType]
    def enabled: Optional[GenericBoolean]
    def ipSets: Optional[List[zio.aws.globalaccelerator.model.IpSet.ReadOnly]]
    def dnsName: Optional[GenericString]
    def status: Optional[zio.aws.globalaccelerator.model.AcceleratorStatus]
    def createdTime: Optional[Timestamp]
    def lastModifiedTime: Optional[Timestamp]
    def getAcceleratorArn: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("acceleratorArn", acceleratorArn)
    def getName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("name", name)
    def getIpAddressType
        : ZIO[Any, AwsError, zio.aws.globalaccelerator.model.IpAddressType] =
      AwsError.unwrapOptionField("ipAddressType", ipAddressType)
    def getEnabled: ZIO[Any, AwsError, GenericBoolean] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getIpSets: ZIO[Any, AwsError, List[
      zio.aws.globalaccelerator.model.IpSet.ReadOnly
    ]] = AwsError.unwrapOptionField("ipSets", ipSets)
    def getDnsName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("dnsName", dnsName)
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.AcceleratorStatus
    ] = AwsError.unwrapOptionField("status", status)
    def getCreatedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdTime", createdTime)
    def getLastModifiedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.Accelerator
  ) extends zio.aws.globalaccelerator.model.Accelerator.ReadOnly {
    override val acceleratorArn: Optional[GenericString] = zio.aws.core.internal
      .optionalFromNullable(impl.acceleratorArn())
      .map(value => value: GenericString)
    override val name: Optional[GenericString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: GenericString)
    override val ipAddressType
        : Optional[zio.aws.globalaccelerator.model.IpAddressType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipAddressType())
        .map(value => zio.aws.globalaccelerator.model.IpAddressType.wrap(value))
    override val enabled: Optional[GenericBoolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: GenericBoolean)
    override val ipSets
        : Optional[List[zio.aws.globalaccelerator.model.IpSet.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipSets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.globalaccelerator.model.IpSet.wrap(item)
          }.toList
        )
    override val dnsName: Optional[GenericString] = zio.aws.core.internal
      .optionalFromNullable(impl.dnsName())
      .map(value => value: GenericString)
    override val status
        : Optional[zio.aws.globalaccelerator.model.AcceleratorStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.globalaccelerator.model.AcceleratorStatus.wrap(value)
        )
    override val createdTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdTime())
      .map(value => zio.aws.globalaccelerator.model.primitives.Timestamp(value))
    override val lastModifiedTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastModifiedTime())
      .map(value => zio.aws.globalaccelerator.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.Accelerator
  ): zio.aws.globalaccelerator.model.Accelerator.ReadOnly = new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-6.20.42.2-sources.jar: zio/aws/globalaccelerator/model/Accelerator.scala <==
package zio.aws.globalaccelerator.model
import zio.aws.globalaccelerator.model.primitives.{
  Timestamp,
  GenericBoolean,
  GenericString
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class Accelerator(
    acceleratorArn: Optional[GenericString] = Optional.Absent,
    name: Optional[GenericString] = Optional.Absent,
    ipAddressType: Optional[zio.aws.globalaccelerator.model.IpAddressType] =
      Optional.Absent,
    enabled: Optional[GenericBoolean] = Optional.Absent,
    ipSets: Optional[Iterable[zio.aws.globalaccelerator.model.IpSet]] =
      Optional.Absent,
    dnsName: Optional[GenericString] = Optional.Absent,
    status: Optional[zio.aws.globalaccelerator.model.AcceleratorStatus] =
      Optional.Absent,
    createdTime: Optional[Timestamp] = Optional.Absent,
    lastModifiedTime: Optional[Timestamp] = Optional.Absent,
    dualStackDnsName: Optional[GenericString] = Optional.Absent,
    events: Optional[
      Iterable[zio.aws.globalaccelerator.model.AcceleratorEvent]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.Accelerator = {
    import Accelerator.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.Accelerator
      .builder()
      .optionallyWith(acceleratorArn.map(value => value: java.lang.String))(
        _.acceleratorArn
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .optionallyWith(
        ipSets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipSets)
      .optionallyWith(dnsName.map(value => value: java.lang.String))(_.dnsName)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        createdTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdTime)
      .optionallyWith(
        lastModifiedTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastModifiedTime)
      .optionallyWith(dualStackDnsName.map(value => value: java.lang.String))(
        _.dualStackDnsName
      )
      .optionallyWith(
        events.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.events)
      .build()
  }
  def asReadOnly: zio.aws.globalaccelerator.model.Accelerator.ReadOnly =
    zio.aws.globalaccelerator.model.Accelerator.wrap(buildAwsValue())
}
object Accelerator {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.Accelerator
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.globalaccelerator.model.Accelerator =
      zio.aws.globalaccelerator.model.Accelerator(
        acceleratorArn.map(value => value),
        name.map(value => value),
        ipAddressType.map(value => value),
        enabled.map(value => value),
        ipSets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dnsName.map(value => value),
        status.map(value => value),
        createdTime.map(value => value),
        lastModifiedTime.map(value => value),
        dualStackDnsName.map(value => value),
        events.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def acceleratorArn: Optional[GenericString]
    def name: Optional[GenericString]
    def ipAddressType: Optional[zio.aws.globalaccelerator.model.IpAddressType]
    def enabled: Optional[GenericBoolean]
    def ipSets: Optional[List[zio.aws.globalaccelerator.model.IpSet.ReadOnly]]
    def dnsName: Optional[GenericString]
    def status: Optional[zio.aws.globalaccelerator.model.AcceleratorStatus]
    def createdTime: Optional[Timestamp]
    def lastModifiedTime: Optional[Timestamp]
    def dualStackDnsName: Optional[GenericString]
    def events: Optional[
      List[zio.aws.globalaccelerator.model.AcceleratorEvent.ReadOnly]
    ]
    def getAcceleratorArn: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("acceleratorArn", acceleratorArn)
    def getName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("name", name)
    def getIpAddressType
        : ZIO[Any, AwsError, zio.aws.globalaccelerator.model.IpAddressType] =
      AwsError.unwrapOptionField("ipAddressType", ipAddressType)
    def getEnabled: ZIO[Any, AwsError, GenericBoolean] =
      AwsError.unwrapOptionField("enabled", enabled)
    def getIpSets: ZIO[Any, AwsError, List[
      zio.aws.globalaccelerator.model.IpSet.ReadOnly
    ]] = AwsError.unwrapOptionField("ipSets", ipSets)
    def getDnsName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("dnsName", dnsName)
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.AcceleratorStatus
    ] = AwsError.unwrapOptionField("status", status)
    def getCreatedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdTime", createdTime)
    def getLastModifiedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModifiedTime", lastModifiedTime)
    def getDualStackDnsName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("dualStackDnsName", dualStackDnsName)
    def getEvents: ZIO[Any, AwsError, List[
      zio.aws.globalaccelerator.model.AcceleratorEvent.ReadOnly
    ]] = AwsError.unwrapOptionField("events", events)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.Accelerator
  ) extends zio.aws.globalaccelerator.model.Accelerator.ReadOnly {
    override val acceleratorArn: Optional[GenericString] = zio.aws.core.internal
      .optionalFromNullable(impl.acceleratorArn())
      .map(value => value: GenericString)
    override val name: Optional[GenericString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: GenericString)
    override val ipAddressType
        : Optional[zio.aws.globalaccelerator.model.IpAddressType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipAddressType())
        .map(value => zio.aws.globalaccelerator.model.IpAddressType.wrap(value))
    override val enabled: Optional[GenericBoolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: GenericBoolean)
    override val ipSets
        : Optional[List[zio.aws.globalaccelerator.model.IpSet.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipSets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.globalaccelerator.model.IpSet.wrap(item)
          }.toList
        )
    override val dnsName: Optional[GenericString] = zio.aws.core.internal
      .optionalFromNullable(impl.dnsName())
      .map(value => value: GenericString)
    override val status
        : Optional[zio.aws.globalaccelerator.model.AcceleratorStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.globalaccelerator.model.AcceleratorStatus.wrap(value)
        )
    override val createdTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdTime())
      .map(value => zio.aws.globalaccelerator.model.primitives.Timestamp(value))
    override val lastModifiedTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastModifiedTime())
      .map(value => zio.aws.globalaccelerator.model.primitives.Timestamp(value))
    override val dualStackDnsName: Optional[GenericString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dualStackDnsName())
        .map(value => value: GenericString)
    override val events: Optional[
      List[zio.aws.globalaccelerator.model.AcceleratorEvent.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.events())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.globalaccelerator.model.AcceleratorEvent.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.Accelerator
  ): zio.aws.globalaccelerator.model.Accelerator.ReadOnly = new Wrapper(impl)
}
